@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for personalize-runtime service client
 
@@ -7,21 +8,18 @@ Usage::
     import boto3
     from mypy_boto3_personalize_runtime import PersonalizeRuntimeClient
 
-    session = boto3.Session()
-
     client: PersonalizeRuntimeClient = boto3.client("personalize-runtime")
-    session_client: PersonalizeRuntimeClient = session.client("personalize-runtime")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING, Type
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_personalize_runtime.type_defs import (
     GetPersonalizedRankingResponseTypeDef,
     GetRecommendationsResponseTypeDef,
 )
 
-
 __all__ = ("PersonalizeRuntimeClient",)
 
 
@@ -33,14 +31,14 @@ class Exceptions:
 
 class PersonalizeRuntimeClient:
     """
-    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -51,14 +49,14 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         """
 
     def get_personalized_ranking(
         self, campaignArn: str, inputList: List[str], userId: str, context: Dict[str, str] = None
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         """
 
     def get_recommendations(
@@ -71,5 +69,5 @@ class PersonalizeRuntimeClient:
         filterArn: str = None,
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         """
